@@ -9,10 +9,11 @@
 #
 package ElasticSearchX::Model::Index;
 {
-  $ElasticSearchX::Model::Index::VERSION = '0.1.6';
+  $ElasticSearchX::Model::Index::VERSION = '0.1.7';
 }
 use Moose;
 use Module::Find ();
+use Class::Load  ();
 use ElasticSearchX::Model::Document::Types qw(:all);
 
 has name => ( is => 'ro' );
@@ -56,7 +57,7 @@ sub _build_types {
         Module::Find::findallmod($namespace),
         grep {/^\Q$namespace\E::/} keys %stash
     );
-    map { Class::MOP::load_class($_) } @found;
+    map { Class::Load::load_class($_) } @found;
     @found = grep {
         $_->isa('Moose::Object')
             && $_->does('ElasticSearchX::Model::Document::Role')
@@ -79,7 +80,7 @@ sub _build_namespace {
 sub type {
     my ( $self, $type ) = @_;
     my $class = $self->get_type($type)->set_class;
-    Class::MOP::load_class($class);
+    Class::Load::load_class($class);
     return $class->new(
         index => $self,
         type  => $self->get_type($type),
@@ -129,13 +130,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 ElasticSearchX::Model::Index
 
 =head1 VERSION
 
-version 0.1.6
+version 0.1.7
 
 =head1 ATTRIBUTES
 
